package com.gree.mall.contest.controller.pc.admin;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.gree.mall.contest.bean.admin.AdminRoleBean;
import com.gree.mall.contest.exception.RemoteServiceException;
import com.gree.mall.contest.helper.ResponseHelper;
import com.gree.mall.contest.logic.admin.AdminRoleLogic;
import com.gree.mall.contest.plus.entity.AdminRole;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;

@Slf4j
@RestController
@Tag(name = "系统角色管理", description = "系统角色管理" )
@RequestMapping(value = "/pc/admin/role", produces = "application/json; charset=utf-8")
@RequiredArgsConstructor
public class AdminRoleController {


    private final AdminRoleLogic adminRoleLogic;

    @GetMapping("/list")
    @Operation(summary = "角色列表")
    public ResponseHelper<IPage<AdminRoleBean>> list(
            HttpServletRequest request,
            @Parameter(description = "部门",required = false) @RequestParam(required = false) String adminWebsitId,
            @Parameter(description = "页号",required = true) @RequestParam(required = true) Integer pageNum,
            @Parameter(description = "页大小",required = true) @RequestParam(required = true) Integer pageSize
    ) throws RemoteServiceException {
        IPage<AdminRoleBean> adminRoleIPage = adminRoleLogic.listPage(request,adminWebsitId,pageNum, pageSize);
        return ResponseHelper.success(adminRoleIPage);
    }

    @GetMapping("/detail")
    @Operation(summary = "角色详情")
    public ResponseHelper<AdminRole> detail(
            @Parameter(description = "角色id",required = true) @RequestParam(required = true) String adminRoleId
    ) throws RemoteServiceException {
        AdminRole detail = adminRoleLogic.detail(adminRoleId);
        return ResponseHelper.success(detail);
    }

    @PostMapping("/add")
    @Operation(summary = "新增角色")
    public ResponseHelper add(
            HttpServletRequest request,
            @RequestBody AdminRole adminRole
    ) throws RemoteServiceException {
        adminRoleLogic.add(request,adminRole);
        return ResponseHelper.success();
    }

    @PostMapping("/update")
    @Operation(summary = "修改角色")
    public ResponseHelper update(@RequestBody AdminRole adminRole) throws RemoteServiceException {
        adminRoleLogic.update(adminRole);
        return ResponseHelper.success();
    }

    @PostMapping("/delete")
    @Operation(summary = "删除角色")
    public ResponseHelper delete(
            @Parameter(description = "角色id",required = true) @RequestParam String adminRoleId
    ) throws RemoteServiceException {
        adminRoleLogic.delete(adminRoleId);
        return ResponseHelper.success();
    }

}
