package com.gree.mall.contest.controller.pc.admin;

import com.gree.mall.contest.bean.admin.AdminWebsitTree;
import com.gree.mall.contest.exception.RemoteServiceException;
import com.gree.mall.contest.helper.ResponseHelper;
import com.gree.mall.contest.logic.admin.AdminWebsitLogic;
import com.gree.mall.contest.plus.entity.AdminWebsit;
import com.gree.mall.contest.plus.entity.AdminWebsitRegion;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import me.chanjar.weixin.common.error.WxErrorException;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import java.util.List;

@Slf4j
@RestController
@Tag(name = "部门管理API", description = "部门管理API")
@RequestMapping(value = "/pc/admin/websit", produces = "application/json; charset=utf-8")
@RequiredArgsConstructor
public class AdminWebsitController {

    private final AdminWebsitLogic adminWebsitLogic;

    @GetMapping("/tree")
    @Operation(summary = "部门树")
    public ResponseHelper<AdminWebsitTree> tree(HttpServletRequest request,
                                                @Parameter(description = "角色查询",required = false)
                                                @RequestParam(required = false,defaultValue = "false") Boolean isRole
                                                ){
        List<AdminWebsitTree> tree = adminWebsitLogic.tree(request,isRole);
        return ResponseHelper.success(tree);
    }

    @GetMapping("/list")
    @Operation(summary = "部门列表")
    public ResponseHelper<List<AdminWebsit>> list(
            @RequestParam(required = false) Boolean isAll,
            @RequestParam(required = false) Boolean status
    ){
        List<AdminWebsit> list = adminWebsitLogic.list(isAll,status);
        return ResponseHelper.success(list);
    }


    @PostMapping("/add")
    @Operation(summary = "新增部门")
    public ResponseHelper add(@RequestBody AdminWebsit adminWebsit, HttpServletRequest request) throws RemoteServiceException, WxErrorException {
        adminWebsitLogic.add(adminWebsit,request);
        return ResponseHelper.success();
    }

    @PostMapping("/update")
    @Operation(summary = "修改部门")
    public ResponseHelper update(@RequestBody AdminWebsit adminWebsit,HttpServletRequest request) throws RemoteServiceException, WxErrorException {
        adminWebsitLogic.update(adminWebsit,request);
        return ResponseHelper.success();
    }

    @PostMapping("/delete")
    @Operation(summary = "删除部门")
    public ResponseHelper delete(@RequestParam String id, HttpServletRequest request) throws WxErrorException {
        adminWebsitLogic.delete(id,request);
        return ResponseHelper.success();
    }

    @GetMapping("/detail")
    @Operation(summary = "部门详情")
    public ResponseHelper<AdminWebsit> detail(@RequestParam String id){
        AdminWebsit detail = adminWebsitLogic.detail(id);
        return ResponseHelper.success(detail);
    }

    @PostMapping("/region/save")
    @Operation(summary = "保存部门服务区域")
    public ResponseHelper<List<AdminWebsitRegion>> saveRegion(
            @RequestBody List<AdminWebsitRegion> adminWebsitRegions
    ){
        adminWebsitLogic.saveRegion(adminWebsitRegions);
        return ResponseHelper.success();
    }

    @PostMapping("/region/list")
    @Operation(summary = "部门服务区域列表")
    public ResponseHelper<List<AdminWebsitRegion>> listRegion(
            @RequestParam String adminWebsitId,
            @Parameter(description = "关键词",required = false) @RequestParam(required = false) String keyword,
            @Parameter(description = "服务类目id",required = false) @RequestParam(required = false) String serviceCategoryId
    ){
        List<AdminWebsitRegion> adminWebsitRegions = adminWebsitLogic.listRegion(adminWebsitId,keyword,serviceCategoryId);
        return ResponseHelper.success(adminWebsitRegions);
    }

    @PostMapping("/region/delete")
    @Operation(summary = "删除部门服务区域")
    public ResponseHelper deleteRegion(
            @RequestParam String id
    ){
        adminWebsitLogic.deleteRegion(id);
        return ResponseHelper.success();
    }

}
